/*
 *	smtp.h
 *
 *	header for SMTP
 */

#define	SMTP_MAXARG	80
#define	SMTP_MAXBUF	1024
#define	SMTP_STAT_NONE	0
#define	SMTP_STAT_HELO	1
#define	SMTP_STAT_AUTH	2
#define	SMTP_STAT_DATA	3
#define	SMTP_TMPFLAGS	00007
#define	SMTP_CONTINUED	00001
#define	SMTP_HASFROM	00002
#define	SMTP_XUSR	00010

extern char *smtp_domain;
extern char *smtp_reverse;
extern char **smtp_forward;
extern int smtp_status;
extern int smtp_flags;

/* smtp.c */
extern char *smtp_parse __P_((CONST char *, ALLOC_T, XFILE *));
extern int smtp_spool __P_((XFILE *));

/* smtprecv.c */
extern int smtp_receive __P_((XFILE *, XFILE *));

/* smtpsend.c */
extern int smtp_send __P_((XFILE *, int, CONST char *fmt, ...));
extern int smtp_senderror __P_((XFILE *));
extern int smtp_greeting __P_((XFILE *));
